@@ -1,4 +1,4 @@
-from imitate import *
+from imitatebias.imitate import *
 from sklearn.model_selection import train_test_split
 from sklearn.metrics import silhouette_score
 from sklearn.cluster import KMeans
